@@ -12,16 +12,16 @@
  *	for default icon set (Glance)
  *
  * This software is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public License
+ * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2.1 of
  * the License, or (at your option) any later version.
  *
  * This software is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
+ * You should have received a copy of the GNU weather-config.h General Public
  * License along with this software; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
  * 02110-1301 USA
@@ -876,6 +876,23 @@ gint read_config(AppletConfig * config) {
     if (config->view_mode < COLLAPSED_VIEW_MODE
                 || config->mode > EXPANDED_VIEW_MODE)
                         config->view_mode = COLLAPSED_VIEW_MODE;
+
+    /* Get mod Drfault Digia*/
+    tmp = NULL;
+    tmp = gconf_client_get_string(gconf_client,
+                                              GCONF_KEY_MOD,
+                                              &gerror);
+    if (!tmp ||gerror) {
+        config->mod = g_strdup("Digia");
+        if(gerror){
+            g_error_free(gerror);
+            gerror = NULL;
+        }
+    }else
+        config->mod = g_strdup(tmp);
+    if (tmp)
+        g_free(tmp);
+
     check_current_station_id();
     gconf_client_clear_cache(gconf_client);
     g_object_unref(gconf_client);
@@ -1180,6 +1197,12 @@ void config_save(AppletConfig * config) {
     gconf_client_set_int(gconf_client,
                              GCONF_KEY_VIEW_MODE, config->view_mode,
                                                       NULL);
+    /* Save mod */
+    if (config->mod)
+        gconf_client_set_string(gconf_client,
+                                GCONF_KEY_MOD,
+                                config->mod, NULL);
+
     g_object_unref(gconf_client);
 #ifdef DEBUGFUNCTIONCALL
     END_FUNCTION;
