@@ -11,16 +11,16 @@
  *	for default icon set (Glance)
  *
  * This software is free software; you can redistribute it and/or
- /Now* modify it under the terms of the GNU Lesser General Public License
+ /Now* modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2.1 of
  * the License, or (at your option) any later version.
  *
  * This software is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
+ * You should have received a copy of the GNU weather-config.h General Public
  * License along with this software; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
  * 02110-1301 USA
@@ -35,10 +35,13 @@ composition_right_horizontal_day_button(WDB *new_day_button){
     gchar       buffer[2048];
     gchar       tmp_buffer[2048];
     gchar       *day_name;
+    gchar       *image_file = NULL;
     gchar       *begin_of_string;
     gchar       *begin_of_string2;
     GtkWidget   *day = NULL;
     GtkWidget   *temperature = NULL;
+    GtkStyle    *high_style = NULL;
+    GtkStyle    *low_style = NULL;
 
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
@@ -48,8 +51,13 @@ composition_right_horizontal_day_button(WDB *new_day_button){
     /* create day box to contain icon, label and wind image */
     /* background */
     memset(buffer, 0, sizeof(buffer));
-    snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_RIGHT_HORIZONTAL_BACKGROUND);
-    new_day_button->background = gtk_image_new_from_file (buffer);
+
+    new_day_button->background = NULL;
+    image_file = create_presets_image_path(PRESET_RIGHT_HORIZONTAL_BACKGROUND);
+    if (image_file){
+        new_day_button->background = gtk_image_new_from_file (image_file);
+        g_free(image_file);
+    }
 
     gtk_widget_set_size_request(new_day_button->box, 70, 177);
     if (new_day_button->background)
@@ -71,8 +79,9 @@ composition_right_horizontal_day_button(WDB *new_day_button){
         memset(tmp_buffer, 0, sizeof(tmp_buffer));
         memcpy(tmp_buffer, day_name , strlen(day_name) - strlen(begin_of_string));
         snprintf(buffer,sizeof(buffer) - 1,
-                                       "<span stretch='ultracondensed' foreground='%s'>%s</span>",
-                                        PRESET_BIG_FONT_COLOR_BACK, tmp_buffer);
+                                     "<span stretch='ultracondensed'>%s</span>", tmp_buffer);
+        gtk_widget_set_name(day, "omweather_preset_day_label");
+
         gtk_label_set_markup(GTK_LABEL(day), buffer);
         gtk_label_set_justify(GTK_LABEL(day), GTK_JUSTIFY_CENTER);
         set_font(day, PRESET_DAY_FONT, -1);
@@ -83,9 +92,20 @@ composition_right_horizontal_day_button(WDB *new_day_button){
         if (begin_of_string && begin_of_string2)
             memcpy(tmp_buffer, begin_of_string + 1 , strlen(begin_of_string + 1) - strlen(begin_of_string2));
 
+        high_style =  gtk_rc_get_style_by_paths (gtk_widget_get_settings(temperature),
+                                                                       "*.omweather_preset_high_temp_label",
+                                                                       "*.omweather_preset_high_temp_label",
+                                                                       G_OBJECT_TYPE(temperature));
+        low_style =  gtk_rc_get_style_by_paths (gtk_widget_get_settings(temperature),
+                                                                       "*.omweather_preset_low_temp_label",
+                                                                       "*.omweather_preset_low_temp_label",
+                                                                       G_OBJECT_TYPE(temperature));
+
         snprintf(buffer,sizeof(buffer) - 1,
-                                       "<span stretch='ultracondensed' weight=\"bold\" foreground='%s'>%s</span><span stretch='ultracondensed' foreground='%s'>%s</span>",
-                                        PRESET_BIG_FONT_COLOR_FRONT, tmp_buffer, PRESET_FONT_COLOR_LOW_TEMP, 
+                                       "<span stretch='ultracondensed' weight=\"bold\" foreground='#%02x%02x%02x'>%s</span><span stretch='ultracondensed' foreground='#%02x%02x%02x'>%s</span>",
+                                        high_style->fg[0].red >>8, high_style->fg[0].green >>8, high_style->fg[0].blue >>8,
+                                        tmp_buffer, 
+                                        low_style->fg[0].red >>8, low_style->fg[0].green >>8, low_style->fg[0].blue >>8,
                                         begin_of_string2);
     }else
         if(gtk_label_get_text(GTK_LABEL(new_day_button->label)))
@@ -116,11 +136,14 @@ composition_central_horizontal_day_button(WDB *new_day_button)
 {
     gchar       buffer[2048];
     gchar       tmp_buffer[2048];
+    gchar       *image_file = NULL;
     gchar       *day_name;
     gchar       *begin_of_string;
     gchar       *begin_of_string2;
     GtkWidget   *day = NULL;
     GtkWidget   *temperature = NULL;
+    GtkStyle    *high_style = NULL;
+    GtkStyle    *low_style = NULL;
 
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
@@ -130,8 +153,14 @@ composition_central_horizontal_day_button(WDB *new_day_button)
     /* create day box to contain icon, label and wind image */
     /* background */
     memset(buffer, 0, sizeof(buffer));
-    snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_MIDDLE_HORIZONTAL_BACKGROUND);
-    new_day_button->background = gtk_image_new_from_file (buffer);
+
+    new_day_button->background = NULL;
+    image_file = create_presets_image_path(PRESET_MIDDLE_HORIZONTAL_BACKGROUND);
+    if (image_file){
+        new_day_button->background = gtk_image_new_from_file (image_file);
+        g_free(image_file);
+    }
+
 
     gtk_widget_set_size_request(new_day_button->box, 70, 177);
     if (new_day_button->background)
@@ -153,8 +182,8 @@ composition_central_horizontal_day_button(WDB *new_day_button)
         memset(tmp_buffer, 0, sizeof(tmp_buffer));
         memcpy(tmp_buffer, day_name , strlen(day_name) - strlen(begin_of_string));
         snprintf(buffer,sizeof(buffer) - 1,
-                                       "<span stretch='ultracondensed' foreground='%s'>%s</span>",
-                                        PRESET_BIG_FONT_COLOR_BACK, tmp_buffer);
+                                       "<span stretch='ultracondensed'>%s</span>", tmp_buffer);
+        gtk_widget_set_name(day, "omweather_preset_day_label");
         gtk_label_set_markup(GTK_LABEL(day), buffer);
         gtk_label_set_justify(GTK_LABEL(day), GTK_JUSTIFY_CENTER);
         set_font(day, PRESET_DAY_FONT, -1);
@@ -166,10 +195,22 @@ composition_central_horizontal_day_button(WDB *new_day_button)
         if (begin_of_string && begin_of_string2)
             memcpy(tmp_buffer, begin_of_string + 1 , strlen(begin_of_string + 1) - strlen(begin_of_string2));
 
+        high_style =  gtk_rc_get_style_by_paths (gtk_widget_get_settings(temperature),
+                                                                       "*.omweather_preset_high_temp_label",
+                                                                       "*.omweather_preset_high_temp_label",
+                                                                       G_OBJECT_TYPE(temperature));
+        low_style =  gtk_rc_get_style_by_paths (gtk_widget_get_settings(temperature),
+                                                                       "*.omweather_preset_low_temp_label",
+                                                                       "*.omweather_preset_low_temp_label",
+                                                                       G_OBJECT_TYPE(temperature));
+
         snprintf(buffer,sizeof(buffer) - 1,
-                                       "<span stretch='ultracondensed' weight=\"bold\" foreground='%s'>%s</span><span stretch='ultracondensed' foreground='%s'>%s</span>",
-                                        PRESET_BIG_FONT_COLOR_FRONT, tmp_buffer, PRESET_FONT_COLOR_LOW_TEMP, 
+                                       "<span stretch='ultracondensed' weight=\"bold\" foreground='#%02x%02x%02x'>%s</span><span stretch='ultracondensed' foreground='#%02x%02x%02x'>%s</span>",
+                                        high_style->fg[0].red >>8, high_style->fg[0].green >>8, high_style->fg[0].blue >>8,
+                                        tmp_buffer, 
+                                        low_style->fg[0].red >>8, low_style->fg[0].green >>8, low_style->fg[0].blue >>8,
                                         begin_of_string2);
+
     }else
         snprintf(buffer,sizeof(buffer) - 1,
                                        "<span stretch='ultracondensed' foreground='%s'>%s</span>",
@@ -196,11 +237,14 @@ composition_central_vertical_day_button(WDB *new_day_button)
 {
     gchar       buffer[2048];
     gchar       tmp_buffer[2048];
+    gchar       *image_file = NULL;
     gchar       *day_name;
     gchar       *begin_of_string;
     gchar       *begin_of_string2;
     GtkWidget   *day = NULL;
     GtkWidget   *temperature = NULL;
+    GtkStyle    *high_style = NULL;
+    GtkStyle    *low_style = NULL;
 
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
@@ -210,8 +254,14 @@ composition_central_vertical_day_button(WDB *new_day_button)
     /* create day box to contain icon, label and wind image */
     /* background */
     memset(buffer, 0, sizeof(buffer));
-    snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_LEFT_VERTICAL_BACKGROUND);
-    new_day_button->background = gtk_image_new_from_file (buffer);
+
+    new_day_button->background = NULL;
+    image_file = create_presets_image_path(PRESET_LEFT_VERTICAL_BACKGROUND);
+    if (image_file){
+        new_day_button->background = gtk_image_new_from_file (image_file);
+        g_free(image_file);
+    }
+
 
     gtk_widget_set_size_request(new_day_button->box, 70, 200);
     if (new_day_button->background)
@@ -233,8 +283,8 @@ composition_central_vertical_day_button(WDB *new_day_button)
         memset(tmp_buffer, 0, sizeof(tmp_buffer));
         memcpy(tmp_buffer, day_name , strlen(day_name) - strlen(begin_of_string));
         snprintf(buffer,sizeof(buffer) - 1,
-                                       "<span stretch='ultracondensed' foreground='%s'>%s</span>",
-                                        PRESET_BIG_FONT_COLOR_BACK, tmp_buffer);
+                                       "<span stretch='ultracondensed' >%s</span>", tmp_buffer);
+        gtk_widget_set_name(day, "omweather_preset_day_label");
         gtk_label_set_markup(GTK_LABEL(day), buffer);
         gtk_label_set_justify(GTK_LABEL(day), GTK_JUSTIFY_CENTER);
         set_font(day, PRESET_DAY_FONT, -1);
@@ -246,9 +296,20 @@ composition_central_vertical_day_button(WDB *new_day_button)
         if (begin_of_string && begin_of_string2)
             memcpy(tmp_buffer, begin_of_string + 1 , strlen(begin_of_string + 1) - strlen(begin_of_string2));
         temperature = gtk_label_new(NULL);
+        high_style =  gtk_rc_get_style_by_paths (gtk_widget_get_settings(temperature),
+                                                                       "*.omweather_preset_high_temp_label",
+                                                                       "*.omweather_preset_high_temp_label",
+                                                                       G_OBJECT_TYPE(temperature));
+        low_style =  gtk_rc_get_style_by_paths (gtk_widget_get_settings(temperature),
+                                                                       "*.omweather_preset_low_temp_label",
+                                                                       "*.omweather_preset_low_temp_label",
+                                                                       G_OBJECT_TYPE(temperature));
+
         snprintf(buffer,sizeof(buffer) - 1,
-                                       "<span stretch='ultracondensed' weight=\"bold\" foreground='%s'>%s</span><span stretch='ultracondensed' foreground='%s'>%s</span>",
-                                        PRESET_BIG_FONT_COLOR_FRONT, tmp_buffer, PRESET_FONT_COLOR_LOW_TEMP, 
+                                       "<span stretch='ultracondensed' weight=\"bold\" foreground='#%02x%02x%02x'>%s</span><span stretch='ultracondensed' foreground='#%02x%02x%02x'>%s</span>",
+                                        high_style->fg[0].red >>8, high_style->fg[0].green >>8, high_style->fg[0].blue >>8,
+                                        tmp_buffer, 
+                                        low_style->fg[0].red >>8, low_style->fg[0].green >>8, low_style->fg[0].blue >>8,
                                         begin_of_string2);
     }else
         snprintf(buffer,sizeof(buffer) - 1,
@@ -276,11 +337,14 @@ composition_left_vertical_day_button(WDB *new_day_button, gint layout)
 {
     gchar       buffer[2048];
     gchar       tmp_buffer[2048];
+    gchar       *image_file = NULL;
     gchar       *day_name;
     gchar       *begin_of_string;
     gchar       *begin_of_string2;
     GtkWidget   *day = NULL;
     GtkWidget   *temperature = NULL;
+    GtkStyle    *high_style = NULL;
+    GtkStyle    *low_style = NULL;
 
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
@@ -290,8 +354,12 @@ composition_left_vertical_day_button(WDB *new_day_button, gint layout)
     /* create day box to contain icon, label and wind image */
     /* background */
     memset(buffer, 0, sizeof(buffer));
-    snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_LEFT_VERTICAL_BACKGROUND);
-    new_day_button->background = gtk_image_new_from_file (buffer);
+    new_day_button->background = NULL;
+    image_file = create_presets_image_path(PRESET_LEFT_VERTICAL_BACKGROUND);
+    if (image_file){
+        new_day_button->background = gtk_image_new_from_file (image_file);
+        g_free(image_file);
+    }
 
     day = gtk_label_new(NULL);
     day_name = (gchar*)gtk_label_get_text(GTK_LABEL(new_day_button->label));
@@ -303,8 +371,8 @@ composition_left_vertical_day_button(WDB *new_day_button, gint layout)
         memset(tmp_buffer, 0, sizeof(tmp_buffer));
         memcpy(tmp_buffer, day_name , strlen(day_name) - strlen(begin_of_string));
         snprintf(buffer,sizeof(buffer) - 1,
-                                       "<span stretch='ultracondensed' foreground='%s'>%s</span>",
-                                        PRESET_BIG_FONT_COLOR_BACK, tmp_buffer);
+                                       "<span stretch='ultracondensed'>%s</span>", tmp_buffer);
+        gtk_widget_set_name(day, "omweather_preset_day_label");
         gtk_label_set_markup(GTK_LABEL(day), buffer);
         gtk_label_set_justify(GTK_LABEL(day), GTK_JUSTIFY_CENTER);
         set_font(day, PRESET_DAY_FONT, -1);
@@ -315,9 +383,20 @@ composition_left_vertical_day_button(WDB *new_day_button, gint layout)
         begin_of_string2 = strstr(begin_of_string + 1, "\n"); 
         if (begin_of_string && begin_of_string2)
             memcpy(tmp_buffer, begin_of_string + 1 , strlen(begin_of_string + 1) - strlen(begin_of_string2));
+        high_style =  gtk_rc_get_style_by_paths (gtk_widget_get_settings(temperature),
+                                                                       "*.omweather_preset_high_temp_label",
+                                                                       "*.omweather_preset_high_temp_label",
+                                                                       G_OBJECT_TYPE(temperature));
+        low_style =  gtk_rc_get_style_by_paths (gtk_widget_get_settings(temperature),
+                                                                       "*.omweather_preset_low_temp_label",
+                                                                       "*.omweather_preset_low_temp_label",
+                                                                       G_OBJECT_TYPE(temperature));
+
         snprintf(buffer,sizeof(buffer) - 1,
-                                       "<span stretch='ultracondensed' weight=\"bold\" foreground='%s'>%s</span><span stretch='ultracondensed' foreground='%s'>%s</span>",
-                                        PRESET_BIG_FONT_COLOR_FRONT, tmp_buffer, PRESET_FONT_COLOR_LOW_TEMP, 
+                                       "<span stretch='ultracondensed' weight=\"bold\" foreground='#%02x%02x%02x'>%s</span><span stretch='ultracondensed' foreground='#%02x%02x%02x'>%s</span>",
+                                        high_style->fg[0].red >>8, high_style->fg[0].green >>8, high_style->fg[0].blue >>8,
+                                        tmp_buffer, 
+                                        low_style->fg[0].red >>8, low_style->fg[0].green >>8, low_style->fg[0].blue >>8,
                                         begin_of_string2);
     }else
         snprintf(buffer,sizeof(buffer) - 1,
@@ -375,19 +454,28 @@ composition_right_vertical_day_button(WDB *new_day_button, gint layout)
 {
     gchar       buffer[2048];
     gchar       tmp_buffer[2048];
+    gchar       *image_file = NULL;
     gchar       *day_name;
     gchar       *begin_of_string;
     gchar       *begin_of_string2;
     GtkWidget   *day = NULL;
     GtkWidget   *temperature = NULL;
+    GtkStyle    *high_style = NULL;
+    GtkStyle    *low_style = NULL;
 
 
     /* Packing all to the box */
     /* create day box to contain icon, label and wind image */
     /* background */
     memset(buffer, 0, sizeof(buffer));
-    snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_RIGHT_VERTICAL_BACKGROUND);
-    new_day_button->background = gtk_image_new_from_file (buffer);
+
+    new_day_button->background = NULL;
+    image_file = create_presets_image_path(PRESET_RIGHT_VERTICAL_BACKGROUND);
+    if (image_file){
+        new_day_button->background = gtk_image_new_from_file (image_file);
+        g_free(image_file);
+    }
+
 
     day = gtk_label_new(NULL);
     day_name = (gchar*)gtk_label_get_text(GTK_LABEL(new_day_button->label));
@@ -399,9 +487,9 @@ composition_right_vertical_day_button(WDB *new_day_button, gint layout)
         memset(tmp_buffer, 0, sizeof(tmp_buffer));
         memcpy(tmp_buffer, day_name , strlen(day_name) - strlen(begin_of_string));
         snprintf(buffer,sizeof(buffer) - 1,
-                                       "<span stretch='ultracondensed' foreground='%s'>%s</span>",
-                                        PRESET_BIG_FONT_COLOR_BACK, tmp_buffer);
+                                       "<span stretch='ultracondensed'>%s</span>", tmp_buffer);
         gtk_label_set_markup(GTK_LABEL(day), buffer);
+        gtk_widget_set_name(day, "omweather_preset_day_label");
         gtk_label_set_justify(GTK_LABEL(day), GTK_JUSTIFY_CENTER);
         set_font(day, PRESET_DAY_FONT, -1);
         gtk_widget_set_size_request(day, 60, 25);
@@ -411,9 +499,20 @@ composition_right_vertical_day_button(WDB *new_day_button, gint layout)
         begin_of_string2 = strstr(begin_of_string + 1, "\n"); 
         if (begin_of_string && begin_of_string2)
             memcpy(tmp_buffer, begin_of_string + 1 , strlen(begin_of_string + 1) - strlen(begin_of_string2));
+        high_style =  gtk_rc_get_style_by_paths (gtk_widget_get_settings(temperature),
+                                                                       "*.omweather_preset_high_temp_label",
+                                                                       "*.omweather_preset_high_temp_label",
+                                                                       G_OBJECT_TYPE(temperature));
+        low_style =  gtk_rc_get_style_by_paths (gtk_widget_get_settings(temperature),
+                                                                       "*.omweather_preset_low_temp_label",
+                                                                       "*.omweather_preset_low_temp_label",
+                                                                       G_OBJECT_TYPE(temperature));
+
         snprintf(buffer,sizeof(buffer) - 1,
-                                       "<span stretch='ultracondensed' weight=\"bold\" foreground='%s'>%s</span><span stretch='ultracondensed' foreground='%s'>%s</span>",
-                                        PRESET_BIG_FONT_COLOR_FRONT, tmp_buffer, PRESET_FONT_COLOR_LOW_TEMP, 
+                                       "<span stretch='ultracondensed' weight=\"bold\" foreground='#%02x%02x%02x'>%s</span><span stretch='ultracondensed' foreground='#%02x%02x%02x'>%s</span>",
+                                        high_style->fg[0].red >>8, high_style->fg[0].green >>8, high_style->fg[0].blue >>8,
+                                        tmp_buffer, 
+                                        low_style->fg[0].red >>8, low_style->fg[0].green >>8, low_style->fg[0].blue >>8,
                                         begin_of_string2);
     }else
         snprintf(buffer,sizeof(buffer) - 1,
@@ -470,15 +569,17 @@ composition_now(WDB *new_day_button, gint layout)
     gint        xoffset = 0;
     gint        image_xoffset = 0;
     gint        wind_xoffset = 0;
+    gchar       *image_file = NULL;
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
 
     /* create day box to contain icon, label and wind image */
-    memset(buffer, 0, sizeof(buffer));
+    memset(buffer, 0, sizeof(buffer));    
+    new_day_button->background = NULL;
     switch (layout){
         case PRESET_NOW_PLUS_THREE_V:
-            snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_NOW_BACKGROUND_PLUS_THREE_V);
+            image_file = create_presets_image_path(PRESET_NOW_BACKGROUND_PLUS_THREE_V);
             gtk_widget_set_size_request(new_day_button->box, 210, 37+15+106);
             xoffset = 0;
             image_xoffset = 13;
@@ -487,25 +588,28 @@ composition_now(WDB *new_day_button, gint layout)
             gtk_widget_set_size_request(new_day_button->shadow_label, 208, 55);
             break;
         case PRESET_NOW_PLUS_TWO:
-            snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_NOW_BACKGROUND_PLUS_TWO);
+            image_file = create_presets_image_path(PRESET_NOW_BACKGROUND_PLUS_TWO);
             xoffset = 12 + 15;
             gtk_widget_set_size_request(new_day_button->box, xoffset+140+1, 37+15+106);
             break;
         case PRESET_NOW_PLUS_SEVEN:
         case PRESET_NOW_PLUS_THREE_H:
-            snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_NOW_BACKGROUND_HORIZONTAL);
+            image_file = create_presets_image_path(PRESET_NOW_BACKGROUND_HORIZONTAL);
             xoffset = 12 + 15;
             gtk_widget_set_size_request(new_day_button->box, xoffset+138, 37+15+106);
             break;
  
         default:
         case PRESET_NOW:
-            snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_NOW_BACKGROUND);
+            image_file = create_presets_image_path(PRESET_NOW_BACKGROUND);
             xoffset = 12 + 15;
             gtk_widget_set_size_request(new_day_button->box, xoffset+140+1, 37+15+106);
             break;
     }
-    new_day_button->background = gtk_image_new_from_file (buffer);
+    if (image_file){
+        new_day_button->background = gtk_image_new_from_file (image_file);
+        g_free(image_file);
+    }
 /* Packing all to the box */
     if (new_day_button->background)
         gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->background, xoffset, 37+15);
@@ -533,8 +637,9 @@ next_station_preset_now(gint layout)
                     *shadow_station_text = NULL,
                     *background_town = NULL,
                     *station_name_btn = NULL;
-    gchar           *begin_of_string;
+    gchar           *image_file = NULL;
     gchar           buffer[2048];
+    gchar           buffer2[2048];
     gint            x_width = 0;
     gint            x_offset = 0;
 #ifdef DEBUGFUNCTIONCALL
@@ -542,27 +647,37 @@ next_station_preset_now(gint layout)
 #endif
     widget = gtk_fixed_new();
     memset(buffer, 0, sizeof(buffer));
+    memset(buffer2, 0, sizeof(buffer2));
     switch (layout){
         case PRESET_NOW_PLUS_THREE_H:
         case PRESET_NOW_PLUS_SEVEN:
-            snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_NOW_BACKGROUND_TOWN_HORIZONTAL);
-            background_town = gtk_image_new_from_file (buffer);
+            image_file = create_presets_image_path(PRESET_NOW_BACKGROUND_TOWN_HORIZONTAL);
+            if (image_file){
+                background_town = gtk_image_new_from_file (image_file);
+                g_free(image_file);
+            }
             if (background_town)
                 gtk_fixed_put(GTK_FIXED(widget), background_town, 12+15, 0);
             x_width = 138;
             x_offset = 12+15;
             break; 
         case PRESET_NOW_PLUS_TWO:
-            snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_NOW_BACKGROUND_TOWN_PLUS_TWO);
-            background_town = gtk_image_new_from_file (buffer);
+            image_file = create_presets_image_path(PRESET_NOW_BACKGROUND_TOWN_PLUS_TWO);
+            if (image_file){
+                background_town = gtk_image_new_from_file (image_file);
+                g_free(image_file);
+            }
             if (background_town)
                 gtk_fixed_put(GTK_FIXED(widget), background_town, 12+15, 0);
             x_width = 140;
             x_offset = 12+15;
             break;
         case PRESET_NOW_PLUS_THREE_V:
-            snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_NOW_BACKGROUND_TOWN_PLUS_THREE_V);
-            background_town = gtk_image_new_from_file (buffer);
+            image_file = create_presets_image_path(PRESET_NOW_BACKGROUND_TOWN_PLUS_THREE_V);
+            if (image_file){
+                background_town = gtk_image_new_from_file (image_file);
+                g_free(image_file);
+            }
             if (background_town)
                 gtk_fixed_put(GTK_FIXED(widget), background_town, 0, 0);
             x_width = 210;
@@ -570,8 +685,11 @@ next_station_preset_now(gint layout)
             break;
         default:
         case PRESET_NOW:
-            snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_NOW_BACKGROUND_TOWN);
-            background_town = gtk_image_new_from_file (buffer);
+            image_file = create_presets_image_path(PRESET_NOW_BACKGROUND_TOWN);
+            if (image_file){
+                background_town = gtk_image_new_from_file (image_file);
+                g_free(image_file);
+            }
             if (background_town)
                 gtk_fixed_put(GTK_FIXED(widget), background_town, 12+15, 0);
             x_width = 140;
@@ -592,24 +710,21 @@ next_station_preset_now(gint layout)
     station_text = gtk_label_new(NULL);
     if(app->config->current_station_id){
         memset(buffer, 0, sizeof(buffer));
-        sprintf(buffer,"<span stretch='ultracondensed' foreground='%s'>%s</span>",
-                            PRESET_BIG_FONT_COLOR_FRONT, app->config->current_station_name); 
+        sprintf(buffer,"<span stretch='ultracondensed'>%s</span>", app->config->current_station_name); 
 
+        gtk_widget_set_name(station_text, "omweather_preset_station_label");
         gtk_label_set_markup(GTK_LABEL(station_text), buffer);
         gtk_label_set_justify(GTK_LABEL(station_text), GTK_JUSTIFY_CENTER);
         set_font(station_text, PRESET_STATION_FONT, -1);
         gtk_widget_set_size_request(station_text, x_width-4, 30);
         /* Create shadow station name */
-        if ((strlen(PRESET_BIG_FONT_COLOR_FRONT) == strlen(PRESET_BIG_FONT_COLOR_BACK))&&
-            (begin_of_string = strstr(buffer,PRESET_BIG_FONT_COLOR_FRONT))){
-            shadow_station_text = gtk_label_new(NULL);
-            memcpy(begin_of_string, PRESET_BIG_FONT_COLOR_BACK,7);
-            gtk_label_set_markup(GTK_LABEL(shadow_station_text), buffer);
-            gtk_label_set_justify(GTK_LABEL(shadow_station_text), GTK_JUSTIFY_CENTER);
-            set_font(shadow_station_text, PRESET_STATION_FONT, -1);
-            gtk_widget_set_size_request(shadow_station_text, x_width-5, 30);
-        }else
-            shadow_station_text = NULL;
+        shadow_station_text = gtk_label_new(NULL);
+        sprintf(buffer2,"<span stretch='ultracondensed'>%s</span>", app->config->current_station_name); 
+        gtk_widget_set_name(shadow_station_text, "omweather_preset_station_shadow_label");
+        gtk_label_set_markup(GTK_LABEL(shadow_station_text), buffer2);
+        gtk_label_set_justify(GTK_LABEL(shadow_station_text), GTK_JUSTIFY_CENTER);
+        set_font(shadow_station_text, PRESET_STATION_FONT, -1);
+        gtk_widget_set_size_request(shadow_station_text, x_width-5, 30);
     }else{
         station_text = NULL;
         shadow_station_text = NULL;
@@ -636,6 +751,7 @@ fill_weather_day_button_presets(WDB *new_day_button, const char *text, const cha
     gchar       buffer[2048];
     GdkPixbuf   *icon_buffer;
     gchar       *begin_of_string;
+    gchar       *image_file = NULL;
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
@@ -655,9 +771,9 @@ fill_weather_day_button_presets(WDB *new_day_button, const char *text, const cha
     new_day_button->wind_text = gtk_label_new(NULL);
     memset(buffer, 0, sizeof(buffer));
     if (wind_speed != -1)
-        sprintf(buffer,"<span stretch='ultracondensed' foreground='%s'>%.0f</span>",
-                               PRESET_WIND_FONT_COLOR, wind_speed);
-
+        sprintf(buffer,"<span stretch='ultracondensed'>%.0f</span>", wind_speed);
+ 
+    gtk_widget_set_name(new_day_button->wind_text, "omweather_preset_wind_label");
     gtk_label_set_markup(GTK_LABEL(new_day_button->wind_text), buffer);
     gtk_label_set_justify(GTK_LABEL(new_day_button->wind_text), GTK_JUSTIFY_CENTER);
     /* Set font size for label */
@@ -679,34 +795,34 @@ fill_weather_day_button_presets(WDB *new_day_button, const char *text, const cha
     memset(buffer, 0, sizeof(buffer));
     switch (wind_direction){
        case TO_SOUTH:
-            snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_WIND_SOUTH);
+            image_file = create_presets_image_path(PRESET_WIND_SOUTH);
             break;
        case TO_EAST:
-            snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_WIND_EAST);
+            image_file = create_presets_image_path(PRESET_WIND_EAST);
             break;
        case TO_WEST:
-            snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_WIND_WEST);
+            image_file = create_presets_image_path(PRESET_WIND_WEST);
             break;
        case TO_NORTH:
-            snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_WIND_NORTH);
+            image_file = create_presets_image_path(PRESET_WIND_NORTH);
             break;
        case TO_SOUTH_EAST:
-            snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_WIND_SOUTH_EAST);
+            image_file = create_presets_image_path(PRESET_WIND_SOUTH_EAST);
             break;
        case TO_SOUTH_WEST:
-            snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_WIND_SOUTH_WEST);
+            image_file = create_presets_image_path(PRESET_WIND_SOUTH_WEST);
             break;
        case TO_NORTH_EAST:
-            snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_WIND_NORTH_EAST);
+            image_file = create_presets_image_path(PRESET_WIND_NORTH_EAST);
             break;
        case TO_NORTH_WEST:
-            snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_WIND_NORTH_WEST);
+            image_file = create_presets_image_path(PRESET_WIND_NORTH_WEST);
             break;
        default:
-            memset(buffer, 0, sizeof(buffer));
+            image_file = NULL;
     }
 
-    if (buffer[0] != 0){
+    if (image_file){
         switch (app->config->wind_units){
             case 0:
                     wind_speed = wind_speed * 3.6;
@@ -720,14 +836,17 @@ fill_weather_day_button_presets(WDB *new_day_button, const char *text, const cha
         }
 
         if (wind_speed > STRONG_WIND){
-           begin_of_string = strstr(buffer,".png"); 
-           snprintf(begin_of_string, sizeof(buffer) - strlen(buffer) - 1, "%s","_warning.png");
+           begin_of_string = strstr(image_file,".png"); 
+           snprintf(begin_of_string, sizeof(buffer) - strlen(image_file) - 1, "%s","_warning.png");
+           g_free(image_file);
+           image_file = g_strdup(begin_of_string);
         }
 
         /* create day icon buffer */
-        icon_buffer =
-          gdk_pixbuf_new_from_file(buffer,
-                        NULL);
+        if (image_file){
+            icon_buffer = gdk_pixbuf_new_from_file(image_file, NULL);
+            g_free(image_file);
+        }
         if (icon_buffer){
             /* create day icon image from buffer */
 //            new_day_button->wind = create_icon_widget(icon_buffer, icon, icon_size, &app->clutter_objects_in_main_form);
@@ -750,13 +869,17 @@ fill_weather_day_button_preset_now(WDB *new_day_button, const char *text, const
     gchar       buffer[2048];
     GdkPixbuf   *icon_buffer;
     gchar       *begin_of_string;
+    gchar       *image_file = NULL;
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
     /* create day label */
+    memset(buffer, 0, sizeof(buffer));
     new_day_button->label = gtk_label_new(NULL);
-    gtk_label_set_markup(GTK_LABEL(new_day_button->label), text);
+    sprintf(buffer,"<span stretch='ultracondensed'>%s</span>", text);
+    gtk_label_set_markup(GTK_LABEL(new_day_button->label), buffer);
     gtk_label_set_justify(GTK_LABEL(new_day_button->label), GTK_JUSTIFY_CENTER);
+    gtk_widget_set_name(new_day_button->label, "omweather_preset_first_temp");
     /* Set font size for label */
     if ( strlen(text)>65 )
         set_font(new_day_button->label, PRESET_MEDIUM_FONT, -1);
@@ -764,32 +887,24 @@ fill_weather_day_button_preset_now(WDB *new_day_button, const char *text, const
         set_font(new_day_button->label, PRESET_BIG_FONT, -1);
     gtk_widget_set_size_request(new_day_button->label, 140, 52);
 
-/*        gtk_widget_set_name(new_day_button->label, "day_label");*/
     /* create shadow of day label */
-    /* check for memcpy operation */
-    if ((strlen(PRESET_BIG_FONT_COLOR_FRONT) == strlen(PRESET_BIG_FONT_COLOR_BACK))&&
-        (begin_of_string = strstr(text, PRESET_BIG_FONT_COLOR_FRONT))){
-        new_day_button->shadow_label = gtk_label_new(NULL);
-        memcpy(begin_of_string, PRESET_BIG_FONT_COLOR_BACK,7);
-        gtk_label_set_markup(GTK_LABEL(new_day_button->shadow_label), text);
-        gtk_label_set_justify(GTK_LABEL(new_day_button->shadow_label), GTK_JUSTIFY_CENTER);
-        /* Set font size for label */
-        if ( strlen(text)>65 )
-            set_font(new_day_button->shadow_label, PRESET_MEDIUM_FONT, -1);
-        else
-            set_font(new_day_button->shadow_label, PRESET_BIG_FONT, -1);
-        gtk_widget_set_size_request(new_day_button->shadow_label, 140, 52);
-
-     }else
-        new_day_button->shadow_label = NULL;
+    new_day_button->shadow_label = gtk_label_new(NULL);
+    gtk_label_set_markup(GTK_LABEL(new_day_button->shadow_label), buffer);
+    gtk_label_set_justify(GTK_LABEL(new_day_button->shadow_label), GTK_JUSTIFY_CENTER);
+    gtk_widget_set_name(new_day_button->shadow_label, "omweather_preset_first_shadow_temp");
+    /* Set font size for label */
+    if ( strlen(text)>65 )
+        set_font(new_day_button->shadow_label, PRESET_MEDIUM_FONT, -1);
+    else
+        set_font(new_day_button->shadow_label, PRESET_BIG_FONT, -1);
+    gtk_widget_set_size_request(new_day_button->shadow_label, 140, 52);
 
     /* create wind text */
     new_day_button->wind_text = gtk_label_new(NULL);
     memset(buffer, 0, sizeof(buffer));
     if (wind_speed != -1)
-        sprintf(buffer,"<span stretch='ultracondensed' foreground='%s'>%.0f</span>",
-                               PRESET_WIND_FONT_COLOR, wind_speed);
-
+        sprintf(buffer,"<span stretch='ultracondensed'>%.0f</span>", wind_speed);
+    gtk_widget_set_name(new_day_button->wind_text, "omweather_preset_wind_label");
     gtk_label_set_markup(GTK_LABEL(new_day_button->wind_text), buffer);
     gtk_label_set_justify(GTK_LABEL(new_day_button->wind_text), GTK_JUSTIFY_CENTER);
     /* Set font size for label */
@@ -812,33 +927,33 @@ fill_weather_day_button_preset_now(WDB *new_day_button, const char *text, const
     memset(buffer, 0, sizeof(buffer));
     switch (wind_direction){
        case TO_SOUTH:
-            snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_WIND_SOUTH);
+            image_file = create_presets_image_path(PRESET_WIND_SOUTH);
             break;
        case TO_EAST:
-            snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_WIND_EAST);
+            image_file = create_presets_image_path(PRESET_WIND_EAST);
             break;
        case TO_WEST:
-            snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_WIND_WEST);
+            image_file = create_presets_image_path(PRESET_WIND_WEST);
             break;
        case TO_NORTH:
-            snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_WIND_NORTH);
+            image_file = create_presets_image_path(PRESET_WIND_NORTH);
             break;
        case TO_SOUTH_EAST:
-            snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_WIND_SOUTH_EAST);
+            image_file = create_presets_image_path(PRESET_WIND_SOUTH_EAST);
             break;
        case TO_SOUTH_WEST:
-            snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_WIND_SOUTH_WEST);
+            image_file = create_presets_image_path(PRESET_WIND_SOUTH_WEST);
             break;
        case TO_NORTH_EAST:
-            snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_WIND_NORTH_EAST);
+            image_file = create_presets_image_path(PRESET_WIND_NORTH_EAST);
             break;
        case TO_NORTH_WEST:
-            snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_WIND_NORTH_WEST);
+            image_file = create_presets_image_path(PRESET_WIND_NORTH_WEST);
             break;
        default:
-            memset(buffer, 0, sizeof(buffer));
+            image_file = NULL;
     }
-    if (buffer[0] != 0){
+    if (image_file){
         switch (app->config->wind_units){
             case 0:
                     wind_speed = wind_speed * 3.6;
@@ -850,12 +965,13 @@ fill_weather_day_button_preset_now(WDB *new_day_button, const char *text, const
                     wind_speed = wind_speed * 1.6;
                     break;
         }
-        if (wind_speed < STRONG_WIND)
-            new_day_button->wind = gtk_image_new_from_file (buffer);
-        else{
-           begin_of_string = strstr(buffer,".png"); 
-           snprintf(begin_of_string, sizeof(buffer) - strlen(buffer) - 1, "%s","_warning.png");
-           new_day_button->wind = gtk_image_new_from_file (buffer);
+        if (wind_speed < STRONG_WIND){
+            new_day_button->wind = gtk_image_new_from_file (image_file);
+            g_free(image_file);
+        }else{
+           begin_of_string = strstr(image_file,".png"); 
+           snprintf(begin_of_string, sizeof(buffer) - strlen(image_file) - 1, "%s","_warning.png");
+           new_day_button->wind = gtk_image_new_from_file (begin_of_string);
         }
     }
     new_day_button->box  = gtk_fixed_new();
